#!/bin/sh

name="cyrus-sasl"
title="Cyrus SASL"
package="cyrus-sasl"
version="2.1.13"
build="1"
noarch="n"
build_info="Standard build."

info="Generic client/server library for SASL authentication."
desc="The Cyrus SASL library is a generic library for easy
integration of secure network authentication to any
client or server application. It supports
authentication via standard plaintext methods as well
as CRAM-MD5 and DIGEST-MD5 shared secret methods and
KERBEROS_V4 and GSSAPI Kerberos methods. The SASL
protocol framework is used by SMTP, IMAP, ACAP, LDAP,
and other standard protocols."
category="system/authentication"
environment="console/text"
contact="$name@packages.packware.one.pl"
vendor="The Packware Project"
vendor_id="pw"

requires=""
obsoletes=""
conflicts=""

docs_source="AUTHORS,COPYING,ChangeLog,INSTALL,NEWS,README,doc,saslauthd.txt"
docs_cwd=""

strip_bin="y"
reset_own="y"
reset_dir="y"
reset_fil="y"
delete_cat="y"

. /usr/src/tgz/lib/builder.defs

add_source ftp://ftp.andrew.cmu.edu/pub/cyrus-mail/$name-$version.tar.gz

configure_option --prefix=/usr
configure_option --enable-sample=no
configure_option --enable-login
configure_option --enable-plain
configure_option --with-saslauthd=/var/run/saslauthd

install_option DESTDIR=$pkg_main

parent_package="$package"
write_info main

cd $src1

do_configure
do_make
do_install

mkdir -p $pkg_main/var/run/saslauthd
groff -S -wall -mtty-char -Tlatin1 -mdoc saslauthd/saslauthd.mdoc > \
    saslauthd.txt

copy $src_pkg/rc.saslauthd $pkg_main/etc/rc.d
chmod a+x $pkg_main/etc/rc.d/rc.saslauthd

make_docs

rm -f $doc_dir/doc/{Makefile*,ONEWS,windows.html,rfc*,draft*}
mv -f $doc_dir/doc/TODO $doc_dir

make_package main

clean_up

# $Log: cyrus-sasl.builder,v $
# Revision 1.8  2003/04/20 19:34:12  swiergot
# - Build 1.
#
# Revision 1.7  2003/04/20 19:26:37  swiergot
# - Version 2.1.13.
#
# Revision 1.6  2003/03/23 08:24:43  swiergot
# - Build 3.
#
# Revision 1.5  2003/03/22 23:14:27  swiergot
# - Removed configure_option --sysconfdir=/etc/sasl (had no effect).
# - Don't create etc/sasl.
#
# Revision 1.4  2003/03/22 11:57:07  swiergot
# - Build 2.
#
# Revision 1.3  2003/03/22 11:36:26  swiergot
# - Added configure_option --sysconfdir=/etc/sasl.
# - Added configure_option --enable-login.
# - Added configure_option --enable-plain.
# - Create /etc/sasl directory.
#
# Revision 1.2  2003/03/21 20:35:32  swiergot
# - Build 1.
#
# Revision 1.1  2003/03/21 20:07:01  swiergot
# - Initial release.
# - Version 2.1.12.
#
